import xxhash
import unittest


class TestAlgorithmExists(unittest.TestCase):
    def test_xxh32(self):
        xxhash.xxh32
        assert "xxh32" in xxhash.algorithms_available

    def test_xxh64(self):
        xxhash.xxh64
        assert "xxh64" in xxhash.algorithms_available

    def test_xxh3_64(self):
        xxhash.xxh3_64
        assert "xxh3_64" in xxhash.algorithms_available

    def test_xxh128(self):
        xxhash.xxh128
        assert "xxh128" in xxhash.algorithms_available

    def test_xxh3_128(self):
        xxhash.xxh3_128
        assert "xxh3_128" in xxhash.algorithms_available


if __name__ == '__main__':
    unittest.main()



import array
import os
import unittest
import random
import struct
import sys
from typing import Union, List, TYPE_CHECKING
import xxhash

if TYPE_CHECKING:
    InputType = Union[str, bytes, bytearray, memoryview, array.ArrayType[int]]
else:
    InputType = None


def getrefcount(obj):
    if hasattr(sys, "getrefcount"):
        return sys.getrefcount(obj)
    else:
        # Non-CPython implementation
        return 0


class TestXXH(unittest.TestCase):
    def test_version(self):
        self.assertTrue(xxhash.VERSION)
        self.assertTrue(xxhash.XXHASH_VERSION)

    def test_buffer_types(self):
        # Various buffer-like objects are accepted, and they give similar values
        args: List[InputType] = [
            b'ab\x00c',
            bytearray(b'ab\x00c'),
            array.array('b', b'ab\x00c'),
        ]
        # An array object with non-1 itemsize
        a = array.array('i', struct.unpack('i', b'ab\x00c'))
        assert a.itemsize == 4
        args.append(a)
        # A memoryview, where supported
        if sys.version_info >= (2, 7):
            args.append(memoryview(b'ab\x00c'))

        for func in [xxhash.xxh32, xxhash.xxh64, xxhash.xxh3_64, xxhash.xxh3_128]:
            old_refcounts = list(map(getrefcount, args))
            # With constructor
            values = set(func(arg).hexdigest() for arg in args)
            self.assertEqual(len(values), 1, values)
            # With update()
            values = set()
            for arg in args:
                x = func()
                x.update(arg)
                values.add(x.hexdigest())
            self.assertEqual(len(values), 1, values)
            # No reference leak in CPython extension
            del arg
            self.assertEqual(list(map(getrefcount, args)), old_refcounts)


if __name__ == '__main__':
    unittest.main()



import os
import unittest
import random
import xxhash


class TestXXH(unittest.TestCase):
    def test_xxh32(self):
        self.assertEqual(xxhash.xxh32('a').intdigest(), 1426945110)
        self.assertEqual(xxhash.xxh32('a', 0).intdigest(), 1426945110)
        self.assertEqual(xxhash.xxh32('a', 1).intdigest(), 4111757423)
        self.assertEqual(xxhash.xxh32('a', 2**32-1).intdigest(), 3443684653)

    def test_xxh32_intdigest(self):
        self.assertEqual(xxhash.xxh32_intdigest('a'), 1426945110)
        self.assertEqual(xxhash.xxh32_intdigest('a', 0), 1426945110)
        self.assertEqual(xxhash.xxh32_intdigest('a', 1), 4111757423)
        self.assertEqual(xxhash.xxh32_intdigest('a', 2**32-1), 3443684653)

    def test_xxh32_update(self):
        x = xxhash.xxh32()
        x.update('a')
        self.assertEqual(xxhash.xxh32('a').digest(), x.digest())
        self.assertEqual(xxhash.xxh32_digest('a'), x.digest())
        x.update('b')
        self.assertEqual(xxhash.xxh32('ab').digest(), x.digest())
        self.assertEqual(xxhash.xxh32_digest('ab'), x.digest())
        x.update('c')
        self.assertEqual(xxhash.xxh32('abc').digest(), x.digest())
        self.assertEqual(xxhash.xxh32_digest('abc'), x.digest())

        seed = random.randint(0, 2**32)
        x = xxhash.xxh32(seed=seed)
        x.update('a')
        self.assertEqual(xxhash.xxh32('a', seed).digest(), x.digest())
        self.assertEqual(xxhash.xxh32_digest('a', seed), x.digest())
        x.update('b')
        self.assertEqual(xxhash.xxh32('ab', seed).digest(), x.digest())
        self.assertEqual(xxhash.xxh32_digest('ab', seed), x.digest())
        x.update('c')
        self.assertEqual(xxhash.xxh32('abc', seed).digest(), x.digest())
        self.assertEqual(xxhash.xxh32_digest('abc', seed), x.digest())

    def test_xxh32_reset(self):
        x = xxhash.xxh32()
        h = x.intdigest()

        for i in range(10, 50):
            x.update(os.urandom(i))

        x.reset()

        self.assertEqual(h, x.intdigest())

    def test_xxh32_copy(self):
        a = xxhash.xxh32()
        a.update('xxhash')

        b = a.copy()
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())

        b.update('xxhash')
        self.assertNotEqual(a.digest(), b.digest())
        self.assertNotEqual(a.intdigest(), b.intdigest())
        self.assertNotEqual(a.hexdigest(), b.hexdigest())

        a.update('xxhash')
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())

    def test_xxh32_overflow(self):
        s = 'I want an unsigned 32-bit seed!'
        a = xxhash.xxh32(s, seed=0)
        b = xxhash.xxh32(s, seed=2**32)
        self.assertEqual(a.seed, b.seed)
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), xxhash.xxh32_intdigest(s, seed=0))
        self.assertEqual(a.intdigest(), xxhash.xxh32_intdigest(s, seed=2**32))
        self.assertEqual(a.digest(), xxhash.xxh32_digest(s, seed=0))
        self.assertEqual(a.digest(), xxhash.xxh32_digest(s, seed=2**32))
        self.assertEqual(a.hexdigest(), xxhash.xxh32_hexdigest(s, seed=0))
        self.assertEqual(a.hexdigest(), xxhash.xxh32_hexdigest(s, seed=2**32))


        a = xxhash.xxh32(s, seed=1)
        b = xxhash.xxh32(s, seed=2**32+1)
        self.assertEqual(a.seed, b.seed)
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), xxhash.xxh32_intdigest(s, seed=1))
        self.assertEqual(a.intdigest(), xxhash.xxh32_intdigest(s, seed=2**32+1))
        self.assertEqual(a.digest(), xxhash.xxh32_digest(s, seed=1))
        self.assertEqual(a.digest(), xxhash.xxh32_digest(s, seed=2**32+1))
        self.assertEqual(a.hexdigest(), xxhash.xxh32_hexdigest(s, seed=1))
        self.assertEqual(a.hexdigest(), xxhash.xxh32_hexdigest(s, seed=2**32+1))

        a = xxhash.xxh32(s, seed=2**33-1)
        b = xxhash.xxh32(s, seed=2**34-1)
        self.assertEqual(a.seed, b.seed)
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), xxhash.xxh32_intdigest(s, seed=2**33-1))
        self.assertEqual(a.intdigest(), xxhash.xxh32_intdigest(s, seed=2**34-1))
        self.assertEqual(a.digest(), xxhash.xxh32_digest(s, seed=2**33-1))
        self.assertEqual(a.digest(), xxhash.xxh32_digest(s, seed=2**34-1))
        self.assertEqual(a.hexdigest(), xxhash.xxh32_hexdigest(s, seed=2**33-1))
        self.assertEqual(a.hexdigest(), xxhash.xxh32_hexdigest(s, seed=2**34-1))

        a = xxhash.xxh32(s, seed=2**65-1)
        b = xxhash.xxh32(s, seed=2**66-1)
        self.assertEqual(a.seed, b.seed)
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), xxhash.xxh32_intdigest(s, seed=2**65-1))
        self.assertEqual(a.intdigest(), xxhash.xxh32_intdigest(s, seed=2**66-1))
        self.assertEqual(a.digest(), xxhash.xxh32_digest(s, seed=2**65-1))
        self.assertEqual(a.digest(), xxhash.xxh32_digest(s, seed=2**66-1))
        self.assertEqual(a.hexdigest(), xxhash.xxh32_hexdigest(s, seed=2**65-1))
        self.assertEqual(a.hexdigest(), xxhash.xxh32_hexdigest(s, seed=2**66-1))

if __name__ == '__main__':
    unittest.main()



import os
import unittest
import random
import xxhash


class TestName(unittest.TestCase):
    def test_xxh32(self):
        self.assertEqual(xxhash.xxh32().name, "XXH32")

    def test_xxh64(self):
        self.assertEqual(xxhash.xxh64().name, "XXH64")

    def test_xxh3_64(self):
        self.assertEqual(xxhash.xxh3_64().name, "XXH3_64")

    def test_xxh128(self):
        self.assertEqual(xxhash.xxh128().name, "XXH3_128")

    def test_xxh3_128(self):
        self.assertEqual(xxhash.xxh3_128().name, "XXH3_128")

if __name__ == '__main__':
    unittest.main()



import os
import unittest
import random
import xxhash

class TestXXH(unittest.TestCase):
    def test_xxh64(self):
        self.assertEqual(xxhash.xxh64('a').intdigest(), 15154266338359012955)
        self.assertEqual(xxhash.xxh64('a', 0).intdigest(), 15154266338359012955)
        self.assertEqual(xxhash.xxh64('a', 1).intdigest(), 16051599287423682246)
        self.assertEqual(xxhash.xxh64('a', 2**64-1).intdigest(), 6972758980737027682)

    def test_xxh64_intdigest(self):
        self.assertEqual(xxhash.xxh64_intdigest('a'), 15154266338359012955)
        self.assertEqual(xxhash.xxh64_intdigest('a', 0), 15154266338359012955)
        self.assertEqual(xxhash.xxh64_intdigest('a', 1), 16051599287423682246)
        self.assertEqual(xxhash.xxh64_intdigest('a', 2**64-1), 6972758980737027682)

    def test_xxh64_update(self):
        x = xxhash.xxh64()
        x.update('a')
        self.assertEqual(xxhash.xxh64('a').digest(), x.digest())
        self.assertEqual(xxhash.xxh64_digest('a'), x.digest())
        x.update('b')
        self.assertEqual(xxhash.xxh64('ab').digest(), x.digest())
        self.assertEqual(xxhash.xxh64_digest('ab'), x.digest())
        x.update('c')
        self.assertEqual(xxhash.xxh64('abc').digest(), x.digest())
        self.assertEqual(xxhash.xxh64_digest('abc'), x.digest())

        seed = random.randint(0, 2**64)
        x = xxhash.xxh64(seed=seed)
        x.update('a')
        self.assertEqual(xxhash.xxh64('a', seed).digest(), x.digest())
        self.assertEqual(xxhash.xxh64_digest('a', seed), x.digest())
        x.update('b')
        self.assertEqual(xxhash.xxh64('ab', seed).digest(), x.digest())
        self.assertEqual(xxhash.xxh64_digest('ab', seed), x.digest())
        x.update('c')
        self.assertEqual(xxhash.xxh64('abc', seed).digest(), x.digest())
        self.assertEqual(xxhash.xxh64_digest('abc', seed), x.digest())

    def test_xxh64_reset(self):
        x = xxhash.xxh64()
        h = x.intdigest()

        for i in range(10, 50):
            x.update(os.urandom(i))

        x.reset()

        self.assertEqual(h, x.intdigest())

    def test_xxh64_copy(self):
        a = xxhash.xxh64()
        a.update('xxhash')

        b = a.copy()
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())

        b.update('xxhash')
        self.assertNotEqual(a.digest(), b.digest())
        self.assertNotEqual(a.intdigest(), b.intdigest())
        self.assertNotEqual(a.hexdigest(), b.hexdigest())

        a.update('xxhash')
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())

    def test_xxh64_overflow(self):
        s = 'I want an unsigned 64-bit seed!'
        a = xxhash.xxh64(s, seed=0)
        b = xxhash.xxh64(s, seed=2**64)
        self.assertEqual(a.seed, b.seed)
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), xxhash.xxh64_intdigest(s, seed=0))
        self.assertEqual(a.intdigest(), xxhash.xxh64_intdigest(s, seed=2**64))
        self.assertEqual(a.digest(), xxhash.xxh64_digest(s, seed=0))
        self.assertEqual(a.digest(), xxhash.xxh64_digest(s, seed=2**64))
        self.assertEqual(a.hexdigest(), xxhash.xxh64_hexdigest(s, seed=0))
        self.assertEqual(a.hexdigest(), xxhash.xxh64_hexdigest(s, seed=2**64))

        a = xxhash.xxh64(s, seed=1)
        b = xxhash.xxh64(s, seed=2**64+1)
        self.assertEqual(a.seed, b.seed)
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), xxhash.xxh64_intdigest(s, seed=1))
        self.assertEqual(a.intdigest(), xxhash.xxh64_intdigest(s, seed=2**64+1))
        self.assertEqual(a.digest(), xxhash.xxh64_digest(s, seed=1))
        self.assertEqual(a.digest(), xxhash.xxh64_digest(s, seed=2**64+1))
        self.assertEqual(a.hexdigest(), xxhash.xxh64_hexdigest(s, seed=1))
        self.assertEqual(a.hexdigest(), xxhash.xxh64_hexdigest(s, seed=2**64+1))

        a = xxhash.xxh64(s, seed=2**65-1)
        b = xxhash.xxh64(s, seed=2**66-1)
        self.assertEqual(a.seed, b.seed)
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), xxhash.xxh64_intdigest(s, seed=2**65-1))
        self.assertEqual(a.intdigest(), xxhash.xxh64_intdigest(s, seed=2**66-1))
        self.assertEqual(a.digest(), xxhash.xxh64_digest(s, seed=2**65-1))
        self.assertEqual(a.digest(), xxhash.xxh64_digest(s, seed=2**66-1))
        self.assertEqual(a.hexdigest(), xxhash.xxh64_hexdigest(s, seed=2**65-1))
        self.assertEqual(a.hexdigest(), xxhash.xxh64_hexdigest(s, seed=2**66-1))


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python


from setuptools import setup, Extension
import os
import codecs
from pathlib import Path


if os.getenv('XXHASH_LINK_SO'):
    libraries = ['xxhash']
    source = ['src/_xxhash.c']
    include_dirs = []
else:
    libraries = []
    source = ['src/_xxhash.c', 'deps/xxhash/xxhash.c']
    include_dirs = ['deps/xxhash']

ext_modules = [
    Extension(
        '_xxhash',
        source,
        include_dirs=include_dirs,
        libraries=libraries,
    )
]

def readfile(filename):
    with codecs.open(filename, encoding='utf-8', mode='r') as f:
        return f.read()

long_description = readfile('README.rst') + '\n' + readfile('CHANGELOG.rst')

version_dict = {}
exec(Path(__file__).parent.joinpath("xxhash", "version.py").read_text(), {}, version_dict)
version = version_dict["VERSION"]

setup(
    name='xxhash',
    version=version,
    description="Python binding for xxHash",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    author='Yue Du',
    author_email='ifduyue@gmail.com',
    url='https://github.com/ifduyue/python-xxhash',
    license='BSD',
    packages=['xxhash'],
    ext_package='xxhash',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: BSD License',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: Implementation :: CPython',
    ],
    python_requires=">=3.7",
    ext_modules=ext_modules,
    package_data={"xxhash": ["py.typed", "**.pyi"]},
)



import os
import unittest
import random
import xxhash


class TestXXH(unittest.TestCase):
    def test_xxh3_128(self):
        self.assertEqual(xxhash.xxh3_128('a').intdigest(), 225219434562328483135862406050043285023)
        self.assertEqual(xxhash.xxh3_128('a', 0).intdigest(), 225219434562328483135862406050043285023)
        self.assertEqual(xxhash.xxh3_128('a', 1).intdigest(), 337425133163118381928709500770786453280)
        self.assertEqual(xxhash.xxh3_128('a', 2**64-1).intdigest(), 198297796855923085494266857744987477846)

    def test_xxh3_128_intdigest(self):
        self.assertEqual(xxhash.xxh3_128_intdigest('a'), 225219434562328483135862406050043285023)
        self.assertEqual(xxhash.xxh3_128_intdigest('a', 0), 225219434562328483135862406050043285023)
        self.assertEqual(xxhash.xxh3_128_intdigest('a', 1), 337425133163118381928709500770786453280)
        self.assertEqual(xxhash.xxh3_128_intdigest('a', 2**64-1), 198297796855923085494266857744987477846)

    def test_xxh3_128_update(self):
        x = xxhash.xxh3_128()
        x.update('a')
        self.assertEqual(xxhash.xxh3_128('a').digest(), x.digest())
        self.assertEqual(xxhash.xxh3_128_digest('a'), x.digest())
        x.update('b')
        self.assertEqual(xxhash.xxh3_128('ab').digest(), x.digest())
        self.assertEqual(xxhash.xxh3_128_digest('ab'), x.digest())
        x.update('c')
        self.assertEqual(xxhash.xxh3_128('abc').digest(), x.digest())
        self.assertEqual(xxhash.xxh3_128_digest('abc'), x.digest())

        seed = random.randint(0, 2**64)
        x = xxhash.xxh3_128(seed=seed)
        x.update('a')
        self.assertEqual(xxhash.xxh3_128('a', seed).digest(), x.digest())
        self.assertEqual(xxhash.xxh3_128_digest('a', seed), x.digest())
        x.update('b')
        self.assertEqual(xxhash.xxh3_128('ab', seed).digest(), x.digest())
        self.assertEqual(xxhash.xxh3_128_digest('ab', seed), x.digest())
        x.update('c')
        self.assertEqual(xxhash.xxh3_128('abc', seed).digest(), x.digest())
        self.assertEqual(xxhash.xxh3_128_digest('abc', seed), x.digest())

    def test_xxh3_128_reset(self):
        x = xxhash.xxh3_128()
        h = x.intdigest()
        x.update('x' * 10240)
        x.reset()
        self.assertEqual(h, x.intdigest())

    def test_xxh3_128_seed_reset(self):
        seed = random.randint(0, 2**64-1)
        x = xxhash.xxh3_128(seed=seed)
        h = x.intdigest()
        x.update('x' * 10240)
        x.reset()
        self.assertEqual(h, x.intdigest())

    def test_xxh3_128_reset_more(self):
        x = xxhash.xxh3_128()
        h = x.intdigest()

        for i in range(random.randint(100, 200)):
            x.reset()

        for i in range(10, 1000):
            x.update(os.urandom(i))
        x.reset()

        self.assertEqual(h, x.intdigest())

        for i in range(10, 1000):
            x.update(os.urandom(100))
        x.reset()

        self.assertEqual(h, x.intdigest())

    def test_xxh3_128_seed_reset_more(self):
        seed = random.randint(0, 2**64-1)
        x = xxhash.xxh3_128(seed=seed)
        h = x.intdigest()

        for i in range(random.randint(100, 200)):
            x.reset()

        for i in range(10, 1000):
            x.update(os.urandom(i))
        x.reset()

        self.assertEqual(h, x.intdigest())

        for i in range(10, 1000):
            x.update(os.urandom(100))
        x.reset()

        self.assertEqual(h, x.intdigest())

    def test_xxh3_128_copy(self):
        a = xxhash.xxh3_128()
        a.update('xxhash')

        b = a.copy()
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())

        b.update('xxhash')
        self.assertNotEqual(a.digest(), b.digest())
        self.assertNotEqual(a.intdigest(), b.intdigest())
        self.assertNotEqual(a.hexdigest(), b.hexdigest())

        a.update('xxhash')
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())

    def test_xxh3_128_overflow(self):
        s = 'I want an unsigned 64-bit seed!'
        a = xxhash.xxh3_128(s, seed=0)
        b = xxhash.xxh3_128(s, seed=2**64)
        self.assertEqual(a.seed, b.seed)
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), xxhash.xxh3_128_intdigest(s, seed=0))
        self.assertEqual(a.intdigest(), xxhash.xxh3_128_intdigest(s, seed=2**64))
        self.assertEqual(a.digest(), xxhash.xxh3_128_digest(s, seed=0))
        self.assertEqual(a.digest(), xxhash.xxh3_128_digest(s, seed=2**64))
        self.assertEqual(a.hexdigest(), xxhash.xxh3_128_hexdigest(s, seed=0))
        self.assertEqual(a.hexdigest(), xxhash.xxh3_128_hexdigest(s, seed=2**64))

        a = xxhash.xxh3_128(s, seed=1)
        b = xxhash.xxh3_128(s, seed=2**64+1)
        self.assertEqual(a.seed, b.seed)
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), xxhash.xxh3_128_intdigest(s, seed=1))
        self.assertEqual(a.intdigest(), xxhash.xxh3_128_intdigest(s, seed=2**64+1))
        self.assertEqual(a.digest(), xxhash.xxh3_128_digest(s, seed=1))
        self.assertEqual(a.digest(), xxhash.xxh3_128_digest(s, seed=2**64+1))
        self.assertEqual(a.hexdigest(), xxhash.xxh3_128_hexdigest(s, seed=1))
        self.assertEqual(a.hexdigest(), xxhash.xxh3_128_hexdigest(s, seed=2**64+1))

        a = xxhash.xxh3_128(s, seed=2**65-1)
        b = xxhash.xxh3_128(s, seed=2**66-1)
        self.assertEqual(a.seed, b.seed)
        self.assertEqual(a.intdigest(), b.intdigest())
        self.assertEqual(a.hexdigest(), b.hexdigest())
        self.assertEqual(a.digest(), b.digest())
        self.assertEqual(a.intdigest(), xxhash.xxh3_128_intdigest(s, seed=2**65-1))
        self.assertEqual(a.intdigest(), xxhash.xxh3_128_intdigest(s, seed=2**66-1))
        self.assertEqual(a.digest(), xxhash.xxh3_128_digest(s, seed=2**65-1))
        self.assertEqual(a.digest(), xxhash.xxh3_128_digest(s, seed=2**66-1))
        self.assertEqual(a.hexdigest(), xxhash.xxh3_128_hexdigest(s, seed=2**65-1))
        self.assertEqual(a.hexdigest(), xxhash.xxh3_128_hexdigest(s, seed=2**66-1))



if __name__ == '__main__':
    unittest.main()
